import { InjectionToken, Directive, ElementRef, Inject, Input, Optional, ChangeDetectionStrategy, Component, ViewChild, ViewEncapsulation, NgModule } from '@angular/core';
import { NgControl } from '@angular/forms';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @abstract
 */
class EditorBase {
    /**
     * @param {?} editorControl
     * @param {?} _config
     */
    constructor(editorControl, _config) {
        this.editorControl = editorControl;
        this._config = _config;
        this.propagateChange = (_) => {
        };
        this.propagateTouched = () => {
        };
        editorControl.valueAccessor = this;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        const /** @type {?} */ control = this.editorControl.control;
        control.setValidators(control.validator);
        control.updateValueAndValidity();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        $(this._editor.nativeElement).trumbowyg(Object.assign({}, this._config, this.options)).on('tbwinit', () => {
            $(this._editor.nativeElement).trumbowyg(this._disabled ? 'disable' : 'enable');
            this.setContent(this._initValue);
        }).on('tbwchange', () => {
            this.propagateChange(this.getContent());
        }).on('tbwblur', () => {
            this.propagateTouched();
        });
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.propagateTouched = fn;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        this._initValue = value;
        if (this._editor && this._editor.nativeElement) {
            this.setContent(value);
        }
    }
    /**
     * @param {?} disabled
     * @return {?}
     */
    setDisabledState(disabled) {
        this._disabled = disabled;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        $(this._editor.nativeElement).trumbowyg('destroy');
    }
    /**
     * @param {?} content
     * @return {?}
     */
    setContent(content) {
        $(this._editor.nativeElement).trumbowyg('html', content);
    }
    /**
     * @return {?}
     */
    getContent() {
        return $(this._editor.nativeElement).trumbowyg('html');
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const TRUMBOWYG_OPTIONS = new InjectionToken('Trumbowyg options');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EditorDirective extends EditorBase {
    /**
     * @param {?} editorControl
     * @param {?} _config
     * @param {?} _editor
     */
    constructor(editorControl, _config, _editor) {
        super(editorControl, _config);
        this.editorControl = editorControl;
        this._config = _config;
        this._editor = _editor;
    }
}
EditorDirective.decorators = [
    { type: Directive, args: [{
                selector: '[trumbowygNgxEditor]'
            },] },
];
/** @nocollapse */
EditorDirective.ctorParameters = () => [
    { type: NgControl, },
    { type: undefined, decorators: [{ type: Inject, args: [TRUMBOWYG_OPTIONS,] }, { type: Optional },] },
    { type: ElementRef, },
];
EditorDirective.propDecorators = {
    "options": [{ type: Input },],
    "placeholder": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EditorComponent extends EditorBase {
    /**
     * @param {?} editorControl
     * @param {?} _config
     */
    constructor(editorControl, _config) {
        super(editorControl, _config);
        this.editorControl = editorControl;
        this._config = _config;
    }
}
EditorComponent.decorators = [
    { type: Component, args: [{
                selector: 'trumbowyg-ngx-editor',
                template: `<textarea #editor [placeholder]="placeholder ? placeholder : ''"></textarea>
`,
                styles: [``],
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            },] },
];
/** @nocollapse */
EditorComponent.ctorParameters = () => [
    { type: NgControl, },
    { type: undefined, decorators: [{ type: Inject, args: [TRUMBOWYG_OPTIONS,] }, { type: Optional },] },
];
EditorComponent.propDecorators = {
    "options": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "_editor": [{ type: ViewChild, args: ['editor',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TrumbowygNgxModule {
    /**
     * @param {?} options
     * @return {?}
     */
    static withConfig(options) {
        return {
            ngModule: TrumbowygNgxModule,
            providers: [
                { provide: TRUMBOWYG_OPTIONS, useValue: options }
            ]
        };
    }
}
TrumbowygNgxModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    EditorComponent,
                    EditorDirective
                ],
                exports: [
                    EditorComponent,
                    EditorDirective
                ]
            },] },
];
/** @nocollapse */
TrumbowygNgxModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { TrumbowygNgxModule, EditorComponent as ɵa, TRUMBOWYG_OPTIONS as ɵd, EditorDirective as ɵe, EditorBase as ɵb };
//# sourceMappingURL=trumbowyg-ngx.js.map
